@@ -15,7 +15,7 @@ class DeviceFirmwareError(DeviceError):
     """
     def __init__(self, message):
         self.message = message
-        super().__init__(f"Firmware error: {message}")
+        super().__init__(f"{message}")
 
 class DeviceResponseError(DeviceError):
     """
